ImageData

Struct ImageData 

pub struct ImageData<'a> { /* private fields */ }
image data

Implementations

Source

impl ImageData<'_>

pub fn pixels(&self) -> &[u8]

get pixel values encoded as bytes.

this is guaranteed to be a prefix of the buffer passed to decode_png.

pub fn palette(&self, index: u8) -> [u8; 4]

get color in palette at index.

returns [0, 0, 0, 255] if index is out of range.

pub fn width(&self) -> u32

image width in pixels

pub fn height(&self) -> u32

image height in pixels

pub fn bit_depth(&self) -> BitDepth

bits per sample of image

pub fn color_type(&self) -> ColorType

number and type of color channels

pub fn bytes_per_row(&self) -> usize

number of bytes in a single row of pixels

pub fn convert_to_rgba8bpc(&mut self) -> Result<()>

convert self to 8-bits-per-channel RGBA

note: this function can fail with Error::BufferTooSmall if the buffer you allocated is too small! make sure to use ImageHeader::required_bytes_rgba8bpc for this.